@@ -1,82 +1,79 @@
 import os
 import re
 import sys
-import textwrap
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Pattern, Tuple, Union
 
-import rich_click as click
+try:
+    import rich_click as click
 
-from robotidy import skip
-from robotidy.app import Robotidy
+    RICH_PRESENT = True
+except ImportError:  # Fails on vendored-in LSP plugin
+    import click
+
+    RICH_PRESENT = False
+
+from robotidy import app, decorators, exceptions, files, skip, utils, version
 from robotidy.config import Config, FormattingConfig
-from robotidy.decorators import catch_exceptions
-from robotidy.files import DEFAULT_EXCLUDES, find_and_read_config, read_pyproject_config
 from robotidy.rich_console import console
-from robotidy.transformers import load_transformers
-from robotidy.utils import ROBOT_VERSION, RecommendationFinder, TargetVersion, split_args_from_name_or_path
-from robotidy.version import __version__
+from robotidy.transformers import TransformType, load_transformers
 
-click.rich_click.USE_RICH_MARKUP = True
-click.rich_click.USE_MARKDOWN = True
-click.rich_click.STYLE_OPTION = "bold sky_blue3"
-click.rich_click.STYLE_SWITCH = "bold sky_blue3"
-click.rich_click.STYLE_METAVAR = "bold white"
-click.rich_click.STYLE_OPTION_DEFAULT = "grey37"
-click.rich_click.STYLE_OPTIONS_PANEL_BORDER = "grey66"
-click.rich_click.STYLE_USAGE = "magenta"
-click.rich_click.OPTION_GROUPS = {
-    "robotidy": [
-        {
-            "name": "Run only selected transformers",
-            "options": ["--transform"],
-        },
-        {
-            "name": "Work modes",
-            "options": ["--overwrite", "--diff", "--check", "--force-order"],
-        },
-        {
-            "name": "Documentation",
-            "options": ["--list", "--desc"],
-        },
-        {
-            "name": "Configuration",
-            "options": ["--configure", "--config"],
-        },
-        {
-            "name": "Global formatting settings",
-            "options": [
-                "--spacecount",
-                "--indent",
-                "--continuation-indent",
-                "--line-length",
-                "--lineseparator",
-                "--separator",
-                "--startline",
-                "--endline",
-            ],
-        },
-        {"name": "File exclusion", "options": ["--exclude", "--extend-exclude", "--skip-gitignore"]},
-        skip.option_group,
-        {
-            "name": "Other",
-            "options": ["--target-version", "--verbose", "--color", "--output", "--version", "--help"],
-        },
-    ],
-}
+CLI_OPTIONS_LIST = [
+    {
+        "name": "Run only selected transformers",
+        "options": ["--transform"],
+    },
+    {
+        "name": "Work modes",
+        "options": ["--overwrite", "--diff", "--check", "--force-order"],
+    },
+    {
+        "name": "Documentation",
+        "options": ["--list", "--desc"],
+    },
+    {
+        "name": "Configuration",
+        "options": ["--configure", "--config"],
+    },
+    {
+        "name": "Global formatting settings",
+        "options": [
+            "--spacecount",
+            "--indent",
+            "--continuation-indent",
+            "--line-length",
+            "--lineseparator",
+            "--separator",
+            "--startline",
+            "--endline",
+        ],
+    },
+    {"name": "File exclusion", "options": ["--exclude", "--extend-exclude", "--skip-gitignore"]},
+    skip.option_group,
+    {
+        "name": "Other",
+        "options": ["--target-version", "--language", "--verbose", "--color", "--output", "--version", "--help"],
+    },
+]
+
+if RICH_PRESENT:
+    click.rich_click.USE_RICH_MARKUP = True
+    click.rich_click.USE_MARKDOWN = True
+    click.rich_click.STYLE_OPTION = "bold sky_blue3"
+    click.rich_click.STYLE_SWITCH = "bold sky_blue3"
+    click.rich_click.STYLE_METAVAR = "bold white"
+    click.rich_click.STYLE_OPTION_DEFAULT = "grey37"
+    click.rich_click.STYLE_OPTIONS_PANEL_BORDER = "grey66"
+    click.rich_click.STYLE_USAGE = "magenta"
+    click.rich_click.OPTION_GROUPS = {
+        "robotidy": CLI_OPTIONS_LIST,
+        "python -m robotidy": CLI_OPTIONS_LIST,
+    }
 
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 
 
-class TransformType(click.ParamType):
-    name = "transform"
-
-    def convert(self, value, param, ctx):
-        name, args = split_args_from_name_or_path(value.replace(" ", ""))
-        return name, args
-
-
 def parse_opt(opt):
     while opt and opt[0] == "-":
         opt = opt[1:]
@@ -89,7 +86,7 @@ def validate_config_options(params, config):
     allowed = {parse_opt(opt) for param in params for opt in param.opts}
     for conf in config:
         if conf not in allowed:
-            rec_finder = RecommendationFinder()
+            rec_finder = utils.RecommendationFinder()
             similar = rec_finder.find(conf, list(allowed))
             raise click.NoSuchOption(conf, possibilities=similar)
 
@@ -97,9 +94,9 @@ def validate_config_options(params, config):
 def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]) -> Optional[str]:
     # if --config was not used, try to find pyproject.toml or robotidy.toml file
     if value:
-        config = read_pyproject_config(value)
+        config = files.read_pyproject_config(value)
     else:
-        config = find_and_read_config(ctx.params["src"] or (str(Path(".").resolve()),))
+        config = files.find_and_read_config(ctx.params["src"] or (str(Path(".").resolve()),))
     if not config:
         return
     # Sanitize the values to be Click friendly. For more information please see:
@@ -121,7 +118,7 @@ def validate_regex_callback(
     param: click.Parameter,
     value: Optional[str],
 ) -> Optional[Pattern]:
-    return validate_regex(value)
+    return utils.validate_regex(value)
 
 
 def validate_target_version(
@@ -130,47 +127,47 @@ def validate_target_version(
     value: Optional[str],
 ) -> Optional[int]:
     if value is None:
-        return ROBOT_VERSION.major
-    version = TargetVersion[value.upper()].value
-    if version > ROBOT_VERSION.major:
+        return utils.ROBOT_VERSION.major
+    version = utils.TargetVersion[value.upper()].value
+    if version > utils.ROBOT_VERSION.major:
         raise click.BadParameter(
-            f"Target Robot Framework version ({version}) should not be higher than installed version ({ROBOT_VERSION})."
+            f"Target Robot Framework version ({version}) should not be higher than "
+            f"installed version ({utils.ROBOT_VERSION})."
         )
     return version
 
 
-def validate_regex(value: Optional[str]) -> Optional[Pattern]:
-    try:
-        return re.compile(value) if value is not None else None
-    except re.error:
-        raise click.BadParameter("Not a valid regular expression")
+def csv_list_type(ctx: click.Context, param: Union[click.Option, click.Parameter], value: Optional[str]) -> List[str]:
+    if not value:
+        return []
+    return value.split(",")
 
 
-def print_transformer_docs(name, transformer):
+def print_transformer_docs(transformer):
     from rich.markdown import Markdown
 
-    documentation = f"## Transformer {name}\n" + textwrap.dedent(transformer.__doc__)
-    documentation += f"\nSee <https://robotidy.readthedocs.io/en/latest/transformers/{name}.html> for more examples."
-    md = Markdown(documentation, code_theme="native", inline_code_lexer="robotframework")
+    md = Markdown(str(transformer), code_theme="native", inline_code_lexer="robotframework")
     console.print(md)
 
 
+@decorators.optional_rich
 def print_description(name: str, target_version: int):
     transformers = load_transformers(None, {}, allow_disabled=True, target_version=target_version)
-    transformer_by_names = {transformer.__class__.__name__: transformer for transformer in transformers}
+    transformer_by_names = {transformer.name: transformer for transformer in transformers}
     if name == "all":
-        for tr_name, transformer in transformer_by_names.items():
-            print_transformer_docs(tr_name, transformer)
+        for transformer in transformers:
+            print_transformer_docs(transformer)
     elif name in transformer_by_names:
-        print_transformer_docs(name, transformer_by_names[name])
+        print_transformer_docs(transformer_by_names[name])
     else:
-        rec_finder = RecommendationFinder()
+        rec_finder = utils.RecommendationFinder()
         similar = rec_finder.find_similar(name, transformer_by_names.keys())
         click.echo(f"Transformer with the name '{name}' does not exist.{similar}")
         return 1
     return 0
 
 
+@decorators.optional_rich
 def print_transformers_list(target_version: int):
     from rich.table import Table
 
@@ -178,13 +175,11 @@ def print_transformers_list(target_version: int):
     table.add_column("Name", justify="left", no_wrap=True)
     table.add_column("Enabled by default")
     transformers = load_transformers(None, {}, allow_disabled=True, target_version=target_version)
-    transformer_names = []
     for transformer in transformers:
-        enabled = "[bold magenta]No" if not getattr(transformer, "ENABLED", True) else "Yes"
-        transformer_names.append([transformer.__class__.__name__, enabled])
-    for name, enabled in sorted(transformer_names):
-        table.add_row(name, enabled)
+        decorated_enable = "Yes" if transformer.enabled_by_default else "[bold magenta]No"
+        table.add_row(transformer.name, decorated_enable)
     console.print(table)
+    console.print("Transformers are listed in the order they are run by default.")
     console.print(
         "To see detailed docs run:\n"
         "    [bold]robotidy --desc [bold magenta]transformer_name[/][/]\n"
@@ -228,7 +223,7 @@ def print_transformers_list(target_version: int):
         " excluded on recursive searches. An empty value means no paths are excluded."
         " Use forward slashes for directories on all platforms."
     ),
-    show_default=f"{DEFAULT_EXCLUDES}",
+    show_default=f"{files.DEFAULT_EXCLUDES}",
 )
 @click.option(
     "--extend-exclude",
@@ -383,12 +378,20 @@ def print_transformers_list(target_version: int):
 )
 @click.option(
     "--target-version",
-    "-t",
-    type=click.Choice([v.name.lower() for v in TargetVersion], case_sensitive=False),
+    "-tv",
+    type=click.Choice([v.name.lower() for v in utils.TargetVersion], case_sensitive=False),
     callback=validate_target_version,
     help="Only enable transformers supported in set target version",
     show_default="installed Robot Framework version",
 )
+@click.option(
+    "--language",
+    "--lang",
+    callback=csv_list_type,
+    help="Parse Robot Framework files using additional languages.",
+    show_default="en",
+)
+@skip.comments_option
 @skip.documentation_option
 @skip.return_values_option
 @skip.keyword_call_option
@@ -401,9 +404,10 @@ def print_transformers_list(target_version: int):
 @skip.template_option
 @skip.return_option
 @skip.tags_option
-@click.version_option(version=__version__, prog_name="robotidy")
+@skip.block_comments_option
+@click.version_option(version=version.__version__, prog_name="robotidy")
 @click.pass_context
-@catch_exceptions
+@decorators.catch_exceptions
 def cli(
     ctx: click.Context,
     transform: List[Tuple[str, List]],
@@ -431,6 +435,8 @@ def cli(
     output: Optional[Path],
     force_order: bool,
     target_version: int,
+    language: Optional[List[str]],
+    skip_comments: bool,
     skip_documentation: bool,
     skip_return_values: bool,
     skip_keyword_call: List[str],
@@ -443,6 +449,7 @@ def cli(
     skip_template: bool,
     skip_return: bool,
     skip_tags: bool,
+    skip_block_comments: bool,
 ):
     """
     Robotidy is a tool for formatting Robot Framework source code.
@@ -462,7 +469,7 @@ def cli(
             sys.exit(1)
 
     if exclude is None:
-        exclude = re.compile(DEFAULT_EXCLUDES)
+        exclude = re.compile(files.DEFAULT_EXCLUDES)
 
     if config and verbose:
         click.echo(f"Loaded {config} configuration file")
@@ -487,6 +494,8 @@ def cli(
         timeout=skip_timeout,
         return_statement=skip_return,
         tags=skip_tags,
+        comments=skip_comments,
+        block_comments=skip_block_comments,
     )
 
     formatting = FormattingConfig(
@@ -516,7 +525,8 @@ def cli(
         force_order=force_order,
         target_version=target_version,
         color=color,
+        language=language,
     )
-    tidy = Robotidy(config=config)
+    tidy = app.Robotidy(config=config)
     status = tidy.transform_files()
     sys.exit(status)
