@@ -1,3 +1,5 @@
+import re
+
 from robot.api.parsing import Comment, Token
 
 try:
@@ -5,6 +7,7 @@ try:
 except ImportError:
     InlineIfHeader = None
 from robotidy.disablers import skip_if_disabled, skip_section_if_disabled
+from robotidy.skip import Skip
 from robotidy.transformers import Transformer
 from robotidy.utils import ROBOT_VERSION
 
@@ -53,29 +56,40 @@ class SplitTooLongLine(Transformer):
 
     ```robotframework
     *** Test Cases ***
-    Test with default split_on_every_arg
-        # ${arg1} fits under limit, so it stays in the line
-        Keyword With Longer Name    ${arg1}
-        ...    ${arg2}    ${arg3}
-
-    Test with split_on_every_arg = False
+    Test with split_on_every_arg = True (default)
         # arguments are split
         Keyword With Longer Name
         ...    ${arg1}
         ...    ${arg2}
         ...    ${arg3}
+
+    Test with split_on_every_arg = False
+        # ${arg1} fits under limit, so it stays in the line
+        Keyword With Longer Name    ${arg1}
+        ...    ${arg2}    ${arg3}
+
     ```
 
-    Supports global formatting params: ``spacecount``, ``separator``, ``--startline`` and ``--endline``.
+    Supports global formatting params: ``spacecount`` and ``separator``.
     """
 
     IGNORED_WHITESPACE = {Token.EOL, Token.CONTINUATION}
+    HANDLES_SKIP = frozenset({"skip_keyword_call", "skip_keyword_call_pattern"})
 
-    def __init__(self, line_length: int = None, split_on_every_arg: bool = True, split_on_every_value: bool = True):
-        super().__init__()
+    def __init__(
+        self,
+        line_length: int = None,
+        split_on_every_arg: bool = True,
+        split_on_every_value: bool = True,
+        skip: Skip = None,
+    ):
+        super().__init__(skip)
         self._line_length = line_length
         self.split_on_every_arg = split_on_every_arg
         self.split_on_every_value = split_on_every_value
+        self.robocop_disabler_pattern = re.compile(
+            r"(# )+(noqa|robocop: ?(?P<disabler>disable|enable)=?(?P<rules>[\w\-,]*))"
+        )
 
     @property
     def line_length(self):
@@ -97,13 +111,30 @@ class SplitTooLongLine(Transformer):
         return ROBOT_VERSION.major > 4 and isinstance(node.header, InlineIfHeader)
 
     def should_transform_node(self, node):
-        if all(line[-1].end_col_offset < self.line_length for line in node.lines):
+        if not self.any_line_too_long(node):
             return False
-        if not len(node.data_tokens) > 1:  # nothing to split anyway
-            return False
-        return True
+        # find if any line contains more than one data tokens - so we have something to split
+        for line in node.lines:
+            count = 0
+            for token in line:
+                if token.type not in Token.NON_DATA_TOKENS:
+                    count += 1
+                if count > 1:
+                    return True
+        return False
+
+    def any_line_too_long(self, node):
+        for line in node.lines:
+            line = "".join(token.value for token in line)
+            line = self.robocop_disabler_pattern.sub("", line)
+            line = line.rstrip().expandtabs(4)
+            if len(line) >= self.line_length:
+                return True
+        return False
 
     def visit_KeywordCall(self, node):  # noqa
+        if self.skip.keyword_call(node):
+            return node
         if not self.should_transform_node(node):
             return node
         if self.disablers.is_node_disabled(node, full_match=False):
